@@ -5,7 +5,7 @@ output artifact."""
 from ..project import Project
 from ..project import Stage
 from ..steps.models import Output
-from ..utilities.repo import History
+from ..utilities.repo import Revision
 
 
 def is_invalidated(project: Project, stage: Stage, path: str) -> bool:
@@ -17,12 +17,12 @@ def is_invalidated(project: Project, stage: Stage, path: str) -> bool:
     return startswith or touched_dependency is not None
 
 
-def _to_relevant_changes(project: Project, stage: Stage, change_history: list[History]) -> set[str]:
+def _to_relevant_changes(project: Project, stage: Stage, change_history: list[Revision]) -> set[str]:
     output: Output = Output.try_read(project.target_path, stage)
     relevant = set()
     for history in reversed(sorted(change_history, key=lambda c: c.ord)):
         if stage == Stage.DEPLOY or output is None or output.produced_artifact is None \
-                or output.produced_artifact.revision != history.revision:
+                or output.produced_artifact.revision != history.hash:
             relevant.update(history.files_touched)
         else:
             return relevant
@@ -30,7 +30,7 @@ def _to_relevant_changes(project: Project, stage: Stage, change_history: list[Hi
     return relevant
 
 
-def are_invalidated(project: Project, stage: Stage, change_history: list[History]) -> bool:
+def are_invalidated(project: Project, stage: Stage, change_history: list[Revision]) -> bool:
     if project.stages.for_stage(stage) is None:
         return False
 
@@ -39,11 +39,11 @@ def are_invalidated(project: Project, stage: Stage, change_history: list[History
 
 
 def find_invalidated_projects_for_stage(all_projects: set[Project], stage: Stage,
-                                        change_history: list[History]) -> set[Project]:
+                                        change_history: list[Revision]) -> set[Project]:
     return set(filter(lambda p: are_invalidated(p, stage, change_history), all_projects))
 
 
-def find_invalidated_projects_per_stage(all_projects: set[Project], change_history: list[History]) \
+def find_invalidated_projects_per_stage(all_projects: set[Project], change_history: list[Revision]) \
         -> dict[Stage, set[Project]]:
     projects_for_stage = {}
     for stage in Stage:
